![Python package](https://github.com/MichielTukker/WandaToolbox/workflows/Python%20package/badge.svg)
![Upload Python Package](https://github.com/MichielTukker/WandaToolbox/workflows/Upload%20Python%20Package/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/wandatoolbox/badge/?version=latest)](https://wandatoolbox.readthedocs.io/en/latest/?badge=latest)

# Wanda Toolbox
Toolbox (python scripts) for Wanda modellers. This toolbox includes several tools and utilities that can help with Wanda modelling, 
running simulations and analyzing and visualizing simulation results. This module is closely related to PyWanda, the Python bindings for the Wanda API.

Wanda is an advanced water hammer software, designed for engineers by engineers. The Python API bindings can be used to create Wanda models, 
run simulations, and extract the simulation results. The Wanda Toolbox module includes additional scripts to go beyond the basic data retrieval of pywanda.
 

## Installation
Run the following to install this package:

```
pip install WandaToolbox
```

Also see: https://pypi.org/project/wandatoolbox/

## Usage
Tutorial and reference documentation is provided at [wandatoolbox.readthedocs.io](https://wandatoolbox.readthedocs.io). A PDF version of the manual is available [here](https://wandatoolbox.readthedocs.io/_/downloads/en/latest/pdf/). And the source code is always available at [https://github.com/MichielTukker/WandaToolbox](github.com/MichielTukker/WandaToolbox).

## Support
No official support! For questions/improvements/comments, contact Deltares or Wanda support desk?

